package org.davic.net.ca;



import org.davic.resources.*;



/**

 * Objects of this class represent CA sub-systems which can be addressed directly 

 * or indirectly using the semantics of the DAVIC CA0 / DVB Common Interface. 

 * This includes CA sub-systems using that physical interface. It also includes 

 * CA sub-systems using the common interface protocol with other physical 

 * interfaces (e.g. some embedded CA systems). It also may include other CA 

 * sub-systems not using any standardised protocol at all but where there is an 

 * easy mapping between the proprietary protocol and those parts of the common 

 * interface protocol exposed by this API.

 */



public class CA0Module extends CAModule {



  /* For javadoc to hide the non-public constructor */

  CA0Module() {}

  

  /** Returns the manufacturer code of a Common Interface module

    * (table 8.7 of the Common Interface specification). 

    * @exception ModuleUnavailableException raised if the physical CA module

    *                                       has been removed and is not 

    *                                       available any more

    * @return manufacturer code

    */ 

  public int getManufacturerCode() throws CAException {

    return 0;

  }

  

  /** This method allows an application to open a message session to 

    * this module.  The return value of this method is the

    * session_id that is unique identification of the session

    * within the module. 

    * The exceptions are based on Table 7.7 of the Common Interface 

    * specification.

    * @param resource_id the resource in the module to which 

    *                    to communicate. The coding of this parameter

    *                    is defined by Table 8.1 of the Common Interface 

    *                    specification.

    * @param listener listener that will receive the messages related to this

    *                 message session

    * @exception ModuleUnavailableException raised if the physical CA module

    *                                       has been removed and is not 

    *                                       available any more

    * @exception ModuleBusyException raised if the module is busy and 

    *                                is not able to handle a message

    *                                session at the moment

    * @exception ModuleResourceNonExistentException raised if the specified

    *                                               resource is not present

    *                                               in the module

    * @exception ModuleResourceVersionTooLowException raised if the version

    *                                                 of the module resource 

    *                                                 is too low

    * @return the session identifier

    */

  public int openMessageSession(byte[] resource_id,

				MessageListener listener) 

    throws CAException {

      return 0;

    }



  /** This method allows an application to close a session to

    * this module. 

    * After this method has returned, no new messages will be accepted in

    * this session. Messages that have already been submitted will however

    * be answered. After the last 'ModuleResponseEvent' a 

    * 'SessionClosedEvent' will follow.

    * @param session_id the session identifier returned by the 

    *                   openMessageSession method. 

    * @exception ModuleUnavailableException raised if the physical CA module

    *                                       has been removed and is not 

    *                                       available any more

    * @exception UnknownSessionException raised if the specified session does

    *                                    not exist 

    */

  public void closeMessageSession(int session_id) throws CAException {

  }

  

  

  /** Sends a message to a CA0 module. The sending of the message is 

    * asynchronous. 

    * @param session_id the session identifier returned by the 

    *                   openMessageSession method

    * @param msg the message to be sent to the module

    * @exception ModuleUnavailableException raised if the physical CA module

    *                                       has been removed and is not 

    *                                       available any more

    * @exception UnknownSessionException raised if the specified session does

    *                                    not exist 

    * @exception BufferFullException raised if the message buffer is full

    */

  public void sendToModule(int session_id, CA0Message msg) throws CAException {

  }

}




