package org.davic.net.ca;



/** This class represents messages to CA1 modules. <p>

  * Coding of the cla, ins, p1, and p2 parameters is according 

  * to the CA1 specification. 

  */



final public class CA1Message extends CAMessage {



  /** Constructor for a message with no data

    * @param cla the CLA byte of the message

    * @param ins the INS byte of the message

    * @param p1 the P1 byte of the message

    * @param p2 the P2 byte of the message

    */

  public CA1Message(byte cla, byte ins, byte p1, byte p2) {

	super(null);

  }



  /** Constructor for a message with data

    * @param cla the CLA byte of the message

    * @param ins the INS byte of the message

    * @param p1 the P1 byte of the message

    * @param p2 the P2 byte of the message

    * @param data data of the message

    */

  public CA1Message(byte cla, byte ins, byte p1, byte p2, byte[] data) {

	super(data);

  }

  



  /** Constructor for a message with expected response length and data

    * @param cla the CLA byte of the message

    * @param ins the INS byte of the message

    * @param p1 the P1 byte of the message

    * @param p2 the P2 byte of the message

    * @param expectedResponseLength the expected length of the response message

    */  

  public CA1Message(byte cla, byte ins, byte p1, byte p2, 

		    int expectedResponseLength) {

	super(null);

  }

  



  /** Constructor for a message with expected response length and no data

    * @param cla the CLA byte of the message

    * @param ins the INS byte of the message

    * @param p1 the P1 byte of the message

    * @param p2 the P2 byte of the message

    * @param data data of the message

    * @param expectedResponseLength the expected length of the response message

    */  

  public CA1Message(byte cla, byte ins, byte p1, byte p2, byte[] data,

		    int expectedResponseLength) {

	super(data);

  }



  /**

    * @return the CLA byte of the message

    */

  public byte getCla() {

    return (byte) 0;

  }



  /**

    * @return the INS byte of the message

    */

  public byte getIns() {

    return (byte) 0;

  }



  /**

    * @return the P1 byte of the message

    */

  public byte getP1() {

    return (byte) 0;

  }



  /**

    * @return the P2 byte of the message

    */

  public byte getP2() {

    return (byte) 0;

  }



  /** Returns the expected length of the response message.

    * Returns -1, if there is no expected length specified.

    * @return the excepted length of the response

    */

  public int getExpectedLength() {

    return 0;	

  }



  /** Returns the data of the message.

    * Returns null, if the message does not contain the data part.

    * @return the data of the message

    */

  public byte[] getData() {

    return null;

  }

}


